@@ -51,6 +51,7 @@ class SubstreamSlicer(StreamSlicer, JsonSchemaMixin):
         self._options = options
 
     def update_cursor(self, stream_slice: StreamSlice, last_record: Optional[Record] = None):
+        # This method is called after the records are processed.
         cursor = {}
         for parent_stream_config in self.parent_stream_configs:
             slice_value = stream_slice.get(parent_stream_config.stream_slice_field)
@@ -64,7 +65,8 @@ class SubstreamSlicer(StreamSlicer, JsonSchemaMixin):
         stream_slice: Optional[StreamSlice] = None,
         next_page_token: Optional[Mapping[str, Any]] = None,
     ) -> Mapping[str, Any]:
-        return self._get_request_option(RequestOptionType.request_parameter)
+        # Pass the stream_slice from the argument, not the cursor because the cursor is updated after processing the response
+        return self._get_request_option(RequestOptionType.request_parameter, stream_slice)
 
     def get_request_headers(
         self,
@@ -72,7 +74,8 @@ class SubstreamSlicer(StreamSlicer, JsonSchemaMixin):
         stream_slice: Optional[StreamSlice] = None,
         next_page_token: Optional[Mapping[str, Any]] = None,
     ) -> Mapping[str, Any]:
-        return self._get_request_option(RequestOptionType.header)
+        # Pass the stream_slice from the argument, not the cursor because the cursor is updated after processing the response
+        return self._get_request_option(RequestOptionType.header, stream_slice)
 
     def get_request_body_data(
         self,
@@ -80,7 +83,8 @@ class SubstreamSlicer(StreamSlicer, JsonSchemaMixin):
         stream_slice: Optional[StreamSlice] = None,
         next_page_token: Optional[Mapping[str, Any]] = None,
     ) -> Mapping[str, Any]:
-        return self._get_request_option(RequestOptionType.body_data)
+        # Pass the stream_slice from the argument, not the cursor because the cursor is updated after processing the response
+        return self._get_request_option(RequestOptionType.body_data, stream_slice)
 
     def get_request_body_json(
         self,
@@ -88,16 +92,18 @@ class SubstreamSlicer(StreamSlicer, JsonSchemaMixin):
         stream_slice: Optional[StreamSlice] = None,
         next_page_token: Optional[Mapping[str, Any]] = None,
     ) -> Optional[Mapping]:
-        return self._get_request_option(RequestOptionType.body_json)
+        # Pass the stream_slice from the argument, not the cursor because the cursor is updated after processing the response
+        return self._get_request_option(RequestOptionType.body_json, stream_slice)
 
-    def _get_request_option(self, option_type: RequestOptionType):
+    def _get_request_option(self, option_type: RequestOptionType, stream_slice: StreamSlice):
         params = {}
-        for parent_config in self.parent_stream_configs:
-            if parent_config.request_option and parent_config.request_option.inject_into == option_type:
-                key = parent_config.stream_slice_field
-                value = self._cursor.get(key)
-                if value:
-                    params.update({key: value})
+        if stream_slice:
+            for parent_config in self.parent_stream_configs:
+                if parent_config.request_option and parent_config.request_option.inject_into == option_type:
+                    key = parent_config.stream_slice_field
+                    value = stream_slice.get(key)
+                    if value:
+                        params.update({key: value})
         return params
 
     def get_stream_state(self) -> StreamState:
@@ -137,5 +143,4 @@ class SubstreamSlicer(StreamSlicer, JsonSchemaMixin):
                         yield {stream_state_field: stream_state_value, "parent_slice": parent_slice}
                     # If the parent slice contains no records,
                     if empty_parent_slice:
-                        stream_state_value = parent_stream_slice.get(parent_field)
-                        yield {stream_state_field: stream_state_value, "parent_slice": parent_slice}
+                        yield from []
