@@ -54,7 +54,7 @@ def test_simple_retriever_full(mock_http_stream):
     requester.get_method.return_value = http_method
     backoff_time = 60
     should_retry = ResponseStatus.retry(backoff_time)
-    requester.should_retry.return_value = should_retry
+    requester.interpret_response_status.return_value = should_retry
     request_body_json = {"body": "json"}
     requester.request_body_json.return_value = request_body_json
 
@@ -115,24 +115,37 @@ def test_simple_retriever_full(mock_http_stream):
     ],
 )
 def test_should_retry(test_name, requester_response, expected_should_retry, expected_backoff_time):
-    requester = MagicMock()
+    requester = MagicMock(use_cache=False)
     retriever = SimpleRetriever(name="stream_name", primary_key=primary_key, requester=requester, record_selector=MagicMock(), options={})
-    requester.should_retry.return_value = requester_response
+    requester.interpret_response_status.return_value = requester_response
     assert retriever.should_retry(requests.Response()) == expected_should_retry
     if requester_response.action == ResponseAction.RETRY:
         assert retriever.backoff_time(requests.Response()) == expected_backoff_time
 
 
 @pytest.mark.parametrize(
-    "test_name, status_code, response_status, len_expected_records",
+    "test_name, status_code, response_status, len_expected_records, expected_error",
     [
-        ("test_parse_response_fails_if_should_retry_is_fail", 404, response_status.FAIL, None),
-        ("test_parse_response_succeeds_if_should_retry_is_ok", 200, response_status.SUCCESS, 1),
-        ("test_parse_response_succeeds_if_should_retry_is_ignore", 404, response_status.IGNORE, 0),
+        (
+            "test_parse_response_fails_if_should_retry_is_fail",
+            404,
+            response_status.FAIL,
+            None,
+            ReadException("Request None failed with response <Response [404]>"),
+        ),
+        ("test_parse_response_succeeds_if_should_retry_is_ok", 200, response_status.SUCCESS, 1, None),
+        ("test_parse_response_succeeds_if_should_retry_is_ignore", 404, response_status.IGNORE, 0, None),
+        (
+            "test_parse_response_fails_with_custom_error_message",
+            404,
+            ResponseStatus(response_action=ResponseAction.FAIL, error_message="Custom error message override"),
+            None,
+            ReadException("Custom error message override"),
+        ),
     ],
 )
-def test_parse_response(test_name, status_code, response_status, len_expected_records):
-    requester = MagicMock()
+def test_parse_response(test_name, status_code, response_status, len_expected_records, expected_error):
+    requester = MagicMock(use_cache=False)
     record_selector = MagicMock()
     record_selector.select_records.return_value = [{"id": 100}]
     retriever = SimpleRetriever(
@@ -140,13 +153,13 @@ def test_parse_response(test_name, status_code, response_status, len_expected_re
     )
     response = requests.Response()
     response.status_code = status_code
-    requester.should_retry.return_value = response_status
+    requester.interpret_response_status.return_value = response_status
     if len_expected_records is None:
         try:
             retriever.parse_response(response, stream_state={})
             assert False
-        except ReadException:
-            pass
+        except ReadException as actual_exception:
+            assert type(expected_error) is type(actual_exception) and expected_error.args == actual_exception.args
     else:
         records = retriever.parse_response(response, stream_state={})
         assert len(records) == len_expected_records
@@ -162,7 +175,7 @@ def test_parse_response(test_name, status_code, response_status, len_expected_re
     ],
 )
 def test_backoff_time(test_name, response_action, retry_in, expected_backoff_time):
-    requester = MagicMock()
+    requester = MagicMock(use_cache=False)
     record_selector = MagicMock()
     record_selector.select_records.return_value = [{"id": 100}]
     response = requests.Response()
@@ -170,7 +183,7 @@ def test_backoff_time(test_name, response_action, retry_in, expected_backoff_tim
         name="stream_name", primary_key=primary_key, requester=requester, record_selector=record_selector, options={}
     )
     if expected_backoff_time:
-        requester.should_retry.return_value = ResponseStatus(response_action, retry_in)
+        requester.interpret_response_status.return_value = ResponseStatus(response_action, retry_in)
         actual_backoff_time = retriever.backoff_time(response)
         assert expected_backoff_time == actual_backoff_time
     else:
@@ -205,7 +218,7 @@ def test_get_request_options_from_pagination(test_name, paginator_mapping, strea
     stream_slicer.get_request_body_json.return_value = stream_slicer_mapping
 
     base_mapping = {"key": "value"}
-    requester = MagicMock()
+    requester = MagicMock(use_cache=False)
     requester.get_request_params.return_value = base_mapping
     requester.get_request_body_data.return_value = base_mapping
     requester.get_request_body_json.return_value = base_mapping
@@ -251,7 +264,7 @@ def test_get_request_headers(test_name, paginator_mapping, expected_mapping):
     # This test is separate from the other request options because request headers must be strings
     paginator = MagicMock()
     paginator.get_request_headers.return_value = paginator_mapping
-    requester = MagicMock()
+    requester = MagicMock(use_cache=False)
 
     base_mapping = {"key": "value"}
     requester.get_request_headers.return_value = base_mapping
@@ -290,7 +303,7 @@ def test_get_request_headers(test_name, paginator_mapping, expected_mapping):
 def test_request_body_data(test_name, requester_body_data, paginator_body_data, expected_body_data):
     paginator = MagicMock()
     paginator.get_request_body_data.return_value = paginator_body_data
-    requester = MagicMock()
+    requester = MagicMock(use_cache=False)
 
     requester.get_request_body_data.return_value = requester_body_data
 
@@ -325,7 +338,7 @@ def test_request_body_data(test_name, requester_body_data, paginator_body_data,
 def test_path(test_name, requester_path, paginator_path, expected_path):
     paginator = MagicMock()
     paginator.path.return_value = paginator_path
-    requester = MagicMock()
+    requester = MagicMock(use_cache=False)
 
     requester.get_path.return_value = requester_path
 
